@@ -94,11 +94,11 @@ gpointer  data
     GtkWidget *mb;
     int response;
     mb = gtk_message_dialog_new (GTK_WINDOW(app), 
-				 GTK_DIALOG_MODAL,
-				 GTK_MESSAGE_WARNING,
-				 GTK_BUTTONS_YES_NO,
-				 _("Do you really want to restart the current game?"),
-				 NULL);
+			   GTK_DIALOG_MODAL,
+			   GTK_MESSAGE_QUESTION,
+			   GTK_BUTTONS_YES_NO,
+			   _("Are you sure you want to start a new game?"),
+			   NULL);
     response = gtk_dialog_run (GTK_DIALOG(mb));
     gtk_widget_destroy (mb);
     if (response == GTK_RESPONSE_YES) {
@@ -166,7 +166,7 @@ exit_cb(GtkWidget *widget, gpointer  data)
 				 GTK_DIALOG_MODAL,
 				 GTK_MESSAGE_QUESTION,
 				 GTK_BUTTONS_NONE,
-				 _("Do you really want to quit the game?"),
+				 _("Are you sure you want to quit GNOME Robots?"),
 				 NULL);
     gtk_dialog_add_buttons (GTK_DIALOG(mb), GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
 			    GTK_STOCK_QUIT, GTK_RESPONSE_ACCEPT,
@@ -196,7 +196,7 @@ static void about_cb(
 GtkWidget *widget, 
 gpointer data
 ){
-  GtkWidget *about = NULL;
+  static GtkWidget *about = NULL;
   GdkPixbuf *pixbuf = NULL;
   
   const gchar *authors[]= {
@@ -209,6 +209,10 @@ gpointer data
   /* Translator credits */
   gchar *translator_credits = _("translator_credits");
 
+  if (about != NULL) {
+    gtk_window_present (GTK_WINDOW(about));
+    return;
+  }
   {
 	  char *filename = NULL;
 
@@ -222,15 +226,16 @@ gpointer data
 	  }
   }
   
-  about = gnome_about_new(_("Gnobots II"), VERSION,
+  about = gnome_about_new(_("GNOME Robots"), VERSION,
                           "(C) 1998 Mark Rae",
-                          _("Gnome Robots Game"),
+                          _("GNOME Robots Game"),
                           (const char **)authors,
                           (const char **)documenters,
                           strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
                           pixbuf);
   gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW(app));
-  
+  g_signal_connect (G_OBJECT(about), "destroy", G_CALLBACK(gtk_widget_destroyed), &about);
+
   gtk_widget_show(about);
 }
 
